AshDiagram.Renderer.MermaidInk (AshDiagram v0.2.1)
View SourceRenderer for Mermaid diagrams using mermaid.ink web service.
Mix Dependency
This renderer requires the optional dependency :req to be included in
your mix.exs file.
Mermaid Ink Service
mermaid.ink is a third-party service that renders Mermaid diagrams.
- Ensure you understand the privacy implications of using this service.
- Be aware that the service may have usage limits or availability issues.
- Be a good citizen and do not overload the service with excessive requests.